@@ -13,12 +13,12 @@ class MultipleGeneratorsContextManager(object):
         self.generators = generators
 
     def __enter__(self, *args, **kwargs):
-        [g.next() for g in self.generators]
+        [next(g) for g in self.generators]
 
     def __exit__(self, *args, **kwargs):
         for generator in reversed(self.generators):
             try:
-                generator.next()
+                next(generator)
             except StopIteration:
                 pass
 
@@ -34,7 +34,7 @@ class Exam(AssertsMixin):
 
     def __attrs_of_type(self, kind):
         for base in reversed(inspect.getmro(type(self))):
-            for attr, class_value in vars(base).iteritems():
+            for attr, class_value in vars(base).items():
                 resolved_value = getattr(type(self), attr, False)
 
                 if type(resolved_value) is not kind:
